polyplot() plots the universe of 3 objects. polyplot(nobj=4) plots the universe of 4 objects.
Note: 4-object plots require the 'rgl' package to be installed.
References
Thompson, G. L. (1993). Generalized permutation polytopes and exploratory graphical methods for ranked data. The Annals of Statistics, 1401-1430.
#
Heiser, W. J., and D'Ambrosio, A. (2013). Clustering and prediction of rankings within a Kemeny distance framework. In Algorithms from and for Nature and Life (pp. 19-31). Springer International Publishing.
See Also
tabulaterows frequency distribution for ranking data.